@@ -1,6 +1,9 @@
 package main
 
-const STDLIB = "# These are the commands available in an .envrc context\n" +
+const STDLIB = "#!bash\n" +
+	"#\n" +
+	"# These are the commands available in an .envrc context\n" +
+	"#\n" +
 	"set -e\n" +
 	"direnv=\"%s\"\n" +
 	"\n" +
@@ -19,7 +22,8 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#\n" +
 	"log_status() {\n" +
 	"  if [[ -n $DIRENV_LOG_FORMAT ]]; then\n" +
-	"    local msg=\"$*\"\n" +
+	"    local msg=$*\n" +
+	"    # shellcheck disable=SC2059\n" +
 	"    printf \"${DIRENV_LOG_FORMAT}\\n\" \"$msg\" >&2\n" +
 	"  fi\n" +
 	"}\n" +
@@ -41,7 +45,7 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"\n" +
 	"# Usage: expand_path <rel_path> [<relative_to>]\n" +
 	"#\n" +
-	"# Outputs the absolute path of <rel_path> relaitve to <relative_to> or the \n" +
+	"# Outputs the absolute path of <rel_path> relative to <relative_to> or the\n" +
 	"# current directory.\n" +
 	"#\n" +
 	"# Example:\n" +
@@ -77,23 +81,23 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#    # output: /usr/local/lib\n" +
 	"#\n" +
 	"user_rel_path() {\n" +
-	"  local path=\"${1#-}\"\n" +
+	"  local abs_path=${1#-}\n" +
 	"\n" +
-	"  if [ -z \"$path\" ]; then return; fi\n" +
+	"  if [[ -z $abs_path ]]; then return; fi\n" +
 	"\n" +
-	"  if [ -n \"$HOME\" ]; then\n" +
-	"    local rel_path=\"${path#$HOME}\"\n" +
-	"    if [ \"$rel_path\" != \"$path\" ]; then\n" +
-	"      path=\"~${rel_path}\"\n" +
+	"  if [[ -n $HOME ]]; then\n" +
+	"    local rel_path=${abs_path#$HOME}\n" +
+	"    if [[ $rel_path != \"$abs_path\" ]]; then\n" +
+	"      abs_path=~$rel_path\n" +
 	"    fi\n" +
 	"  fi\n" +
 	"\n" +
-	"  echo \"$path\"\n" +
+	"  echo \"$abs_path\"\n" +
 	"}\n" +
 	"\n" +
 	"# Usage: find_up <filename>\n" +
 	"#\n" +
-	"# Outputs the path of <filename> when searched from the current directory up to \n" +
+	"# Outputs the path of <filename> when searched from the current directory up to\n" +
 	"# /. Returns 1 if the file has not been found.\n" +
 	"#\n" +
 	"# Example:\n" +
@@ -109,11 +113,11 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"  (\n" +
 	"    cd \"$(pwd -P 2>/dev/null)\"\n" +
 	"    while true; do\n" +
-	"      if [ -f \"$1\" ]; then\n" +
+	"      if [[ -f $1 ]]; then\n" +
 	"        echo \"$PWD/$1\"\n" +
 	"        return 0\n" +
 	"      fi\n" +
-	"      if [ \"$PWD\" = \"/\" ] || [ \"$PWD\" = \"//\" ]; then\n" +
+	"      if [[ $PWD = / ]] || [[ $PWD = // ]]; then\n" +
 	"        return 1\n" +
 	"      fi\n" +
 	"      cd ..\n" +
@@ -125,16 +129,15 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#\n" +
 	"# Loads another \".envrc\" either by specifying its path or filename.\n" +
 	"source_env() {\n" +
-	"  local rcfile=\"$1\"\n" +
-	"  local rcpath=\"${1/#\\~/$HOME}\"\n" +
-	"  if ! [ -f \"$rcpath\" ]; then\n" +
-	"    rcfile=\"$rcfile/.envrc\"\n" +
-	"    rcpath=\"$rcpath/.envrc\"\n" +
+	"  local rcpath=${1/#\\~/$HOME}\n" +
+	"  local rcfile\n" +
+	"  if ! [[ -f $rcpath ]]; then\n" +
+	"    rcpath=$rcpath/.envrc\n" +
 	"  fi\n" +
+	"  rcfile=$(user_rel_path \"$rcpath\")\n" +
 	"  pushd \"$(pwd -P 2>/dev/null)\" > /dev/null\n" +
 	"    pushd \"$(dirname \"$rcpath\")\" > /dev/null\n" +
-	"    if [ -f \"./$(basename \"$rcpath\")\" ]\n" +
-	"    then\n" +
+	"    if [[ -f ./$(basename \"$rcpath\") ]]; then\n" +
 	"      log_status \"loading $rcfile\"\n" +
 	"      . \"./$(basename \"$rcpath\")\"\n" +
 	"    else\n" +
@@ -149,13 +152,14 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"# Loads another \".envrc\" if found with the find_up command.\n" +
 	"#\n" +
 	"source_up() {\n" +
-	"  local file=\"$1\"\n" +
-	"  if [ -z \"$file\" ]; then\n" +
-	"    file=\".envrc\"\n" +
+	"  local file=$1\n" +
+	"  local dir\n" +
+	"  if [[ -z $file ]]; then\n" +
+	"    file=.envrc\n" +
 	"  fi\n" +
-	"  local path=\"$(cd .. && find_up \"$file\")\"\n" +
-	"  if [ -n \"$path\" ]; then\n" +
-	"    source_env \"$(user_rel_path \"$path\")\"\n" +
+	"  dir=$(cd .. && find_up \"$file\")\n" +
+	"  if [[ -n $dir ]]; then\n" +
+	"    source_env \"$(user_rel_path \"$dir\")\"\n" +
 	"  fi\n" +
 	"}\n" +
 	"\n" +
@@ -168,9 +172,11 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"# the results with direnv_load.\n" +
 	"#\n" +
 	"direnv_load() {\n" +
-	"  exports=\"$(\"$direnv\" apply_dump <(\"$@\"))\"\n" +
-	"  if test \"$?\" -ne 0; then\n" +
-	"    exit 1\n" +
+	"  local exports\n" +
+	"  exports=$(\"$direnv\" apply_dump <(\"$@\"))\n" +
+	"  local es=$?\n" +
+	"  if [[ $es -ne 0 ]]; then\n" +
+	"    return $es\n" +
 	"  fi\n" +
 	"  eval \"$exports\"\n" +
 	"}\n" +
@@ -189,23 +195,25 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#    # output: /home/user/my/project/bin:/usr/bin:/bin\n" +
 	"#\n" +
 	"PATH_add() {\n" +
-	"  export PATH=\"$(expand_path \"$1\"):$PATH\"\n" +
+	"  PATH=$(expand_path \"$1\"):$PATH\n" +
+	"  export PATH\n" +
 	"}\n" +
 	"\n" +
 	"# Usage: path_add <varname> <path>\n" +
 	"#\n" +
 	"# Works like PATH_add except that it's for an arbitrary <varname>.\n" +
 	"path_add() {\n" +
-	"  local old_paths=\"${!1}\"\n" +
-	"  local path=\"$(expand_path \"$2\")\"\n" +
+	"  local old_paths=${!1}\n" +
+	"  local dir\n" +
+	"  dir=$(expand_path \"$2\")\n" +
 	"\n" +
-	"  if [ -z \"$old_paths\" ]; then\n" +
-	"    old_paths=\"$path\"\n" +
+	"  if [[ -z $old_paths ]]; then\n" +
+	"    old_paths=$dir\n" +
 	"  else\n" +
-	"    old_paths=\"$path:$old_paths\"\n" +
+	"    old_paths=$dir:$old_paths\n" +
 	"  fi\n" +
 	"\n" +
-	"  export $1=\"$old_paths\"\n" +
+	"  export $1=$old_paths\n" +
 	"}\n" +
 	"\n" +
 	"# Usage: load_prefix <prefix_path>\n" +
@@ -232,14 +240,15 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#    load_prefix ~/rubies/ruby-1.9.3\n" +
 	"#\n" +
 	"load_prefix() {\n" +
-	"  local path=\"$(expand_path \"$1\")\"\n" +
-	"  path_add CPATH \"$path/include\"\n" +
-	"  path_add LD_LIBRARY_PATH \"$path/lib\"\n" +
-	"  path_add LIBRARY_PATH \"$path/lib\"\n" +
-	"  path_add MANPATH \"$path/man\"\n" +
-	"  path_add MANPATH \"$path/share/man\"\n" +
-	"  path_add PATH \"$path/bin\"\n" +
-	"  path_add PKG_CONFIG_PATH \"$path/lib/pkgconfig\"\n" +
+	"  local dir\n" +
+	"  dir=$(expand_path \"$1\")\n" +
+	"  path_add CPATH \"$dir/include\"\n" +
+	"  path_add LD_LIBRARY_PATH \"$dir/lib\"\n" +
+	"  path_add LIBRARY_PATH \"$dir/lib\"\n" +
+	"  path_add MANPATH \"$dir/man\"\n" +
+	"  path_add MANPATH \"$dir/share/man\"\n" +
+	"  path_add PATH \"$dir/bin\"\n" +
+	"  path_add PKG_CONFIG_PATH \"$dir/lib/pkgconfig\"\n" +
 	"}\n" +
 	"\n" +
 	"# Usage: layout <type>\n" +
@@ -274,8 +283,8 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"# See http://search.cpan.org/dist/local-lib/lib/local/lib.pm for more details\n" +
 	"#\n" +
 	"layout_perl() {\n" +
-	"  local libdir=\"$PWD/.direnv/perl5\"\n" +
-	"  export LOCAL_LIB_DIR=\"$libdir\"\n" +
+	"  local libdir=$PWD/.direnv/perl5\n" +
+	"  export LOCAL_LIB_DIR=$libdir\n" +
 	"  export PERL_MB_OPT=\"--install_base '$libdir'\"\n" +
 	"  export PERL_MM_OPT=\"INSTALL_BASE=$libdir\"\n" +
 	"  path_add PERL5LIB \"$libdir/lib/perl5\"\n" +
@@ -293,14 +302,15 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"# versions of python.\n" +
 	"#\n" +
 	"layout_python() {\n" +
-	"  local python=\"${1:-python}\"\n" +
-	"  local old_env=\"$PWD/.direnv/virtualenv\"\n" +
+	"  local python=${1:-python}\n" +
+	"  local old_env=$PWD/.direnv/virtualenv\n" +
 	"  unset PYTHONHOME\n" +
-	"  if [[ -d $old_env && $python = \"python\" ]]; then\n" +
-	"    export VIRTUAL_ENV=\"$old_virtualenv\"\n" +
+	"  if [[ -d $old_env && $python = python ]]; then\n" +
+	"    export VIRTUAL_ENV=$old_env\n" +
 	"  else\n" +
-	"    local python_version=$(\"$python\" -c \"import platform as p;print(p.python_version())\")\n" +
-	"    export VIRTUAL_ENV=\"$PWD/.direnv/python-$python_version\"\n" +
+	"    local python_version\n" +
+	"    python_version=$(\"$python\" -c \"import platform as p;print(p.python_version())\")\n" +
+	"    export VIRTUAL_ENV=$PWD/.direnv/python-$python_version\n" +
 	"    if [[ ! -d $VIRTUAL_ENV ]]; then\n" +
 	"      virtualenv \"--python=$python\" \"$VIRTUAL_ENV\"\n" +
 	"    fi\n" +
@@ -325,12 +335,13 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#\n" +
 	"layout_ruby() {\n" +
 	"  if ruby -e \"exit Gem::VERSION > '2.2.0'\" 2>/dev/null; then\n" +
-	"    export GEM_HOME=\"$PWD/.direnv/ruby\"\n" +
+	"    export GEM_HOME=$PWD/.direnv/ruby\n" +
 	"  else\n" +
-	"    local ruby_version=\"$(ruby -e\"puts (defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby') + '-' + RUBY_VERSION\")\"\n" +
-	"    export GEM_HOME=\"$PWD/.direnv/ruby-${ruby_version}\"\n" +
+	"    local ruby_version\n" +
+	"    ruby_version=$(ruby -e\"puts (defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby') + '-' + RUBY_VERSION\")\n" +
+	"    export GEM_HOME=$PWD/.direnv/ruby-${ruby_version}\n" +
 	"  fi\n" +
-	"  export BUNDLE_BIN=\"$PWD/.direnv/bin\"\n" +
+	"  export BUNDLE_BIN=$PWD/.direnv/bin\n" +
 	"\n" +
 	"  PATH_add \"$GEM_HOME/bin\"\n" +
 	"  PATH_add \"$BUNDLE_BIN\"\n" +
@@ -350,7 +361,7 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#    # output: Ruby 1.9.3\n" +
 	"#\n" +
 	"use() {\n" +
-	"  local cmd=\"$1\"\n" +
+	"  local cmd=$1\n" +
 	"  log_status \"using $*\"\n" +
 	"  shift\n" +
 	"  \"use_$cmd\" \"$@\"\n" +
@@ -370,9 +381,9 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"#\n" +
 	"rvm() {\n" +
 	"  unset rvm\n" +
-	"  if [ -n \"${rvm_scripts_path:-}\" ]; then\n" +
+	"  if [[ -n ${rvm_scripts_path:-} ]]; then\n" +
 	"    source \"${rvm_scripts_path}/rvm\"\n" +
-	"  elif [ -n \"${rvm_path:-}\" ]; then\n" +
+	"  elif [[ -n ${rvm_path:-} ]]; then\n" +
 	"    source \"${rvm_path}/scripts/rvm\"\n" +
 	"  else\n" +
 	"    source \"$HOME/.rvm/scripts/rvm\"\n" +
@@ -380,7 +391,20 @@ const STDLIB = "# These are the commands available in an .envrc context\n" +
 	"  rvm \"$@\"\n" +
 	"}\n" +
 	"\n" +
+	"# Usage: use_nix [...]\n" +
+	"#\n" +
+	"# Load environment variables from `nix-shell`.\n" +
+	"# If you have a `default.nix` or `shell.nix` these will be\n" +
+	"# used by default, but you can also specify packages directly\n" +
+	"# (e.g `use nix -p ocaml`).\n" +
+	"#\n" +
+	"use_nix() {\n" +
+	"  direnv_load nix-shell --show-trace \"$@\" --run 'direnv dump'\n" +
+	"}\n" +
+	"\n" +
 	"## Load the global ~/.direnvrc if present\n" +
-	"if [ -f \"$HOME/.direnvrc\" ]; then\n" +
-	"  source_env \"~/.direnvrc\" >&2\n" +
+	"if [[ -f ${XDG_CONFIG_HOME:-$HOME/.config}/direnv/direnvrc ]]; then\n" +
+	"  source_env \"${XDG_CONFIG_HOME:-$HOME/.config}/direnv/direnvrc\" >&2\n" +
+	"elif [[ -f $HOME/.direnvrc ]]; then\n" +
+	"  source_env \"$HOME/.direnvrc\" >&2\n" +
 	"fi\n"
