@@ -1,4 +1,7 @@
+#!bash
+#
 # These are the commands available in an .envrc context
+#
 set -e
 direnv="%s"
 
@@ -17,7 +20,8 @@ DIRENV_LOG_FORMAT="${DIRENV_LOG_FORMAT-direnv: %%s}"
 #
 log_status() {
   if [[ -n $DIRENV_LOG_FORMAT ]]; then
-    local msg="$*"
+    local msg=$*
+    # shellcheck disable=SC2059
     printf "${DIRENV_LOG_FORMAT}\n" "$msg" >&2
   fi
 }
@@ -39,7 +43,7 @@ has() {
 
 # Usage: expand_path <rel_path> [<relative_to>]
 #
-# Outputs the absolute path of <rel_path> relaitve to <relative_to> or the 
+# Outputs the absolute path of <rel_path> relative to <relative_to> or the
 # current directory.
 #
 # Example:
@@ -75,23 +79,23 @@ dotenv() {
 #    # output: /usr/local/lib
 #
 user_rel_path() {
-  local path="${1#-}"
+  local abs_path=${1#-}
 
-  if [ -z "$path" ]; then return; fi
+  if [[ -z $abs_path ]]; then return; fi
 
-  if [ -n "$HOME" ]; then
-    local rel_path="${path#$HOME}"
-    if [ "$rel_path" != "$path" ]; then
-      path="~${rel_path}"
+  if [[ -n $HOME ]]; then
+    local rel_path=${abs_path#$HOME}
+    if [[ $rel_path != "$abs_path" ]]; then
+      abs_path=~$rel_path
     fi
   fi
 
-  echo "$path"
+  echo "$abs_path"
 }
 
 # Usage: find_up <filename>
 #
-# Outputs the path of <filename> when searched from the current directory up to 
+# Outputs the path of <filename> when searched from the current directory up to
 # /. Returns 1 if the file has not been found.
 #
 # Example:
@@ -107,11 +111,11 @@ find_up() {
   (
     cd "$(pwd -P 2>/dev/null)"
     while true; do
-      if [ -f "$1" ]; then
+      if [[ -f $1 ]]; then
         echo "$PWD/$1"
         return 0
       fi
-      if [ "$PWD" = "/" ] || [ "$PWD" = "//" ]; then
+      if [[ $PWD = / ]] || [[ $PWD = // ]]; then
         return 1
       fi
       cd ..
@@ -123,16 +127,15 @@ find_up() {
 #
 # Loads another ".envrc" either by specifying its path or filename.
 source_env() {
-  local rcfile="$1"
-  local rcpath="${1/#\~/$HOME}"
-  if ! [ -f "$rcpath" ]; then
-    rcfile="$rcfile/.envrc"
-    rcpath="$rcpath/.envrc"
+  local rcpath=${1/#\~/$HOME}
+  local rcfile
+  if ! [[ -f $rcpath ]]; then
+    rcpath=$rcpath/.envrc
   fi
+  rcfile=$(user_rel_path "$rcpath")
   pushd "$(pwd -P 2>/dev/null)" > /dev/null
     pushd "$(dirname "$rcpath")" > /dev/null
-    if [ -f "./$(basename "$rcpath")" ]
-    then
+    if [[ -f ./$(basename "$rcpath") ]]; then
       log_status "loading $rcfile"
       . "./$(basename "$rcpath")"
     else
@@ -147,13 +150,14 @@ source_env() {
 # Loads another ".envrc" if found with the find_up command.
 #
 source_up() {
-  local file="$1"
-  if [ -z "$file" ]; then
-    file=".envrc"
+  local file=$1
+  local dir
+  if [[ -z $file ]]; then
+    file=.envrc
   fi
-  local path="$(cd .. && find_up "$file")"
-  if [ -n "$path" ]; then
-    source_env "$(user_rel_path "$path")"
+  dir=$(cd .. && find_up "$file")
+  if [[ -n $dir ]]; then
+    source_env "$(user_rel_path "$dir")"
   fi
 }
 
@@ -166,9 +170,11 @@ source_up() {
 # the results with direnv_load.
 #
 direnv_load() {
-  exports="$("$direnv" apply_dump <("$@"))"
-  if test "$?" -ne 0; then
-    exit 1
+  local exports
+  exports=$("$direnv" apply_dump <("$@"))
+  local es=$?
+  if [[ $es -ne 0 ]]; then
+    return $es
   fi
   eval "$exports"
 }
@@ -187,23 +193,25 @@ direnv_load() {
 #    # output: /home/user/my/project/bin:/usr/bin:/bin
 #
 PATH_add() {
-  export PATH="$(expand_path "$1"):$PATH"
+  PATH=$(expand_path "$1"):$PATH
+  export PATH
 }
 
 # Usage: path_add <varname> <path>
 #
 # Works like PATH_add except that it's for an arbitrary <varname>.
 path_add() {
-  local old_paths="${!1}"
-  local path="$(expand_path "$2")"
+  local old_paths=${!1}
+  local dir
+  dir=$(expand_path "$2")
 
-  if [ -z "$old_paths" ]; then
-    old_paths="$path"
+  if [[ -z $old_paths ]]; then
+    old_paths=$dir
   else
-    old_paths="$path:$old_paths"
+    old_paths=$dir:$old_paths
   fi
 
-  export $1="$old_paths"
+  export $1=$old_paths
 }
 
 # Usage: load_prefix <prefix_path>
@@ -230,14 +238,15 @@ path_add() {
 #    load_prefix ~/rubies/ruby-1.9.3
 #
 load_prefix() {
-  local path="$(expand_path "$1")"
-  path_add CPATH "$path/include"
-  path_add LD_LIBRARY_PATH "$path/lib"
-  path_add LIBRARY_PATH "$path/lib"
-  path_add MANPATH "$path/man"
-  path_add MANPATH "$path/share/man"
-  path_add PATH "$path/bin"
-  path_add PKG_CONFIG_PATH "$path/lib/pkgconfig"
+  local dir
+  dir=$(expand_path "$1")
+  path_add CPATH "$dir/include"
+  path_add LD_LIBRARY_PATH "$dir/lib"
+  path_add LIBRARY_PATH "$dir/lib"
+  path_add MANPATH "$dir/man"
+  path_add MANPATH "$dir/share/man"
+  path_add PATH "$dir/bin"
+  path_add PKG_CONFIG_PATH "$dir/lib/pkgconfig"
 }
 
 # Usage: layout <type>
@@ -272,8 +281,8 @@ layout_node() {
 # See http://search.cpan.org/dist/local-lib/lib/local/lib.pm for more details
 #
 layout_perl() {
-  local libdir="$PWD/.direnv/perl5"
-  export LOCAL_LIB_DIR="$libdir"
+  local libdir=$PWD/.direnv/perl5
+  export LOCAL_LIB_DIR=$libdir
   export PERL_MB_OPT="--install_base '$libdir'"
   export PERL_MM_OPT="INSTALL_BASE=$libdir"
   path_add PERL5LIB "$libdir/lib/perl5"
@@ -291,14 +300,15 @@ layout_perl() {
 # versions of python.
 #
 layout_python() {
-  local python="${1:-python}"
-  local old_env="$PWD/.direnv/virtualenv"
+  local python=${1:-python}
+  local old_env=$PWD/.direnv/virtualenv
   unset PYTHONHOME
-  if [[ -d $old_env && $python = "python" ]]; then
-    export VIRTUAL_ENV="$old_virtualenv"
+  if [[ -d $old_env && $python = python ]]; then
+    export VIRTUAL_ENV=$old_env
   else
-    local python_version=$("$python" -c "import platform as p;print(p.python_version())")
-    export VIRTUAL_ENV="$PWD/.direnv/python-$python_version"
+    local python_version
+    python_version=$("$python" -c "import platform as p;print(p.python_version())")
+    export VIRTUAL_ENV=$PWD/.direnv/python-$python_version
     if [[ ! -d $VIRTUAL_ENV ]]; then
       virtualenv "--python=$python" "$VIRTUAL_ENV"
     fi
@@ -323,12 +333,13 @@ layout_python3() {
 #
 layout_ruby() {
   if ruby -e "exit Gem::VERSION > '2.2.0'" 2>/dev/null; then
-    export GEM_HOME="$PWD/.direnv/ruby"
+    export GEM_HOME=$PWD/.direnv/ruby
   else
-    local ruby_version="$(ruby -e"puts (defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby') + '-' + RUBY_VERSION")"
-    export GEM_HOME="$PWD/.direnv/ruby-${ruby_version}"
+    local ruby_version
+    ruby_version=$(ruby -e"puts (defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby') + '-' + RUBY_VERSION")
+    export GEM_HOME=$PWD/.direnv/ruby-${ruby_version}
   fi
-  export BUNDLE_BIN="$PWD/.direnv/bin"
+  export BUNDLE_BIN=$PWD/.direnv/bin
 
   PATH_add "$GEM_HOME/bin"
   PATH_add "$BUNDLE_BIN"
@@ -348,7 +359,7 @@ layout_ruby() {
 #    # output: Ruby 1.9.3
 #
 use() {
-  local cmd="$1"
+  local cmd=$1
   log_status "using $*"
   shift
   "use_$cmd" "$@"
@@ -368,9 +379,9 @@ use_rbenv() {
 #
 rvm() {
   unset rvm
-  if [ -n "${rvm_scripts_path:-}" ]; then
+  if [[ -n ${rvm_scripts_path:-} ]]; then
     source "${rvm_scripts_path}/rvm"
-  elif [ -n "${rvm_path:-}" ]; then
+  elif [[ -n ${rvm_path:-} ]]; then
     source "${rvm_path}/scripts/rvm"
   else
     source "$HOME/.rvm/scripts/rvm"
@@ -378,7 +389,20 @@ rvm() {
   rvm "$@"
 }
 
+# Usage: use_nix [...]
+#
+# Load environment variables from `nix-shell`.
+# If you have a `default.nix` or `shell.nix` these will be
+# used by default, but you can also specify packages directly
+# (e.g `use nix -p ocaml`).
+#
+use_nix() {
+  direnv_load nix-shell --show-trace "$@" --run 'direnv dump'
+}
+
 ## Load the global ~/.direnvrc if present
-if [ -f "$HOME/.direnvrc" ]; then
-  source_env "~/.direnvrc" >&2
+if [[ -f ${XDG_CONFIG_HOME:-$HOME/.config}/direnv/direnvrc ]]; then
+  source_env "${XDG_CONFIG_HOME:-$HOME/.config}/direnv/direnvrc" >&2
+elif [[ -f $HOME/.direnvrc ]]; then
+  source_env "$HOME/.direnvrc" >&2
 fi
